Index: field.api.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/field/field.api.php,v
retrieving revision 1.2
diff -u -r1.2 field.api.php
--- field.api.php	10 Feb 2009 03:16:14 -0000	1.2
+++ field.api.php	7 Mar 2009 16:56:18 -0000
@@ -6,6 +6,9 @@
  * @{
  */
 
+define('FIELD_STORAGE_INSERT', FALSE);
+define('FIELD_STORAGE_UPDATE', TRUE);
+
 /**
  * Inform the Field API about one or more fieldable types (object
  * types to which fields can be attached).
@@ -556,11 +559,11 @@
  *   The entity type of object, such as 'node' or 'user'.
  * @param $object
  *   The object on which to operate.
  * @param $update
  *   TRUE if this is an update to an existing object, FALSE if it is
  *   an insert of a new object.
  */
-function hook_field_storage_write($obj_type, $object, $update = TRUE) {
+function hook_field_storage_write($obj_type, $object, $op = FIELD_STORAGE_UPDATE) {
 }
 
 /**
@@ -556,11 +559,11 @@
  * @param $object
  *   The object on which to operate.
- * @param $update
- *   TRUE if this is an update to an existing object, FALSE if it is
- *   an insert of a new object.
+ * @param $op
+ *   FIELD_STORAGE_UPDATE if this is an update to an existing object,
+ *   FIELD_STORAGE_INSERT if it is an insert of a new object.
  */

